aboutsummaryrefslogtreecommitdiffstats
path: root/test/vpp_interface.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/vpp_interface.py')
-rw-r--r--test/vpp_interface.py10
1 files changed, 7 insertions, 3 deletions
diff --git a/test/vpp_interface.py b/test/vpp_interface.py
index 856a5cc2..9d9712eb 100644
--- a/test/vpp_interface.py
+++ b/test/vpp_interface.py
@@ -195,12 +195,16 @@ class VppInterface(object):
self.has_ip4_config = False
self.has_ip4_config = False
- def configure_ipv4_neighbors(self):
- """For every remote host assign neighbor's MAC to IPv4 addresses."""
+ def configure_ipv4_neighbors(self, vrf_id=0):
+ """For every remote host assign neighbor's MAC to IPv4 addresses.
+
+ :param vrf_id: The FIB table / VRF ID. (Default value = 0)
+ """
for host in self._remote_hosts:
macn = host.mac.replace(":", "").decode('hex')
ipn = host.ip4n
- self.test.vapi.ip_neighbor_add_del(self.sw_if_index, macn, ipn)
+ self.test.vapi.ip_neighbor_add_del(
+ self.sw_if_index, macn, ipn, vrf_id)
def config_ip6(self):
"""Configure IPv6 address on the VPP interface."""